@@ -46,12 +46,19 @@ class PlaylistControls(Gtk.Grid):
     def __repr__(self):
         return '<PlaylistControls>'
 
-    def __init__(self):
+    def __init__(self, application):
+        """Initialize
+
+        :param GtkApplication application: The application object
+        """
         super().__init__()
 
         self._playlist = None
         self._count_id = 0
         self._binding_count = None
+        self._window = application.props.window
+
+        self._play_action = self._window.lookup_action("playlist_play")
 
     @Gtk.Template.Callback()
     @log
@@ -83,6 +90,8 @@ class PlaylistControls(Gtk.Grid):
             "{} Song", "{} Songs", self.props.playlist.count).format(
                 self.props.playlist.count)
 
+        self._play_action.props.enabled = self.props.playlist.props.count > 0
+
     @log
     def enable_rename_playlist(self, pl_torename):
         """Enables rename button and entry
